From: http://www.wireshark.org/lists/wireshark-dev/201103/msg00157.html
authorChris Maynard <Christopher.Maynard@GTECH.COM>
Wed, 23 Mar 2011 20:00:13 +0000 (20:00 -0000)
committerChris Maynard <Christopher.Maynard@GTECH.COM>
Wed, 23 Mar 2011 20:00:13 +0000 (20:00 -0000)
Change RTT references to SRT.
(tshark.pod could use a description for -z afp,srt and -z camel,srt)

svn path=/trunk/; revision=36297

doc/tshark.pod
doc/wireshark.pod.template
mkcap.c
tap-afpstat.c
tap-rpcstat.c
tap-scsistat.c
tap-smbstat.c
tap-wspstat.c

index f5d118c3f20a610afc425a5e740cad25c72766a3..7d94e4e8afd18fe149299d099c055dbebb4145ba 100644 (file)
@@ -655,22 +655,26 @@ Currently implemented statistics are:
 
 =over 4
 
-=item B<-z> dcerpc,rtt,I<uuid>,I<major>.I<minor>[,I<filter>]
+=item B<-z> afp,srt[,I<filter>]
 
-Collect call/reply RTT data for DCERPC interface I<uuid>,
+=item B<-z> camel,srt
+
+=item B<-z> dcerpc,srt,I<uuid>,I<major>.I<minor>[,I<filter>]
+
+Collect call/reply SRT (Service Response Time) data for DCERPC interface I<uuid>,
 version I<major>.I<minor>.
-Data collected is the number of calls for each procedure, MinRTT, MaxRTT
-and AvgRTT.
+Data collected is the number of calls for each procedure, MinSRT, MaxSRT
+and AvgSRT.
 
-Example: S<B<-z dcerpc,rtt,12345778-1234-abcd-ef00-0123456789ac,1.0>> will collect data for the CIFS SAMR Interface.
+Example: S<B<-z dcerpc,srt,12345778-1234-abcd-ef00-0123456789ac,1.0>> will collect data for the CIFS SAMR Interface.
+
+This option can be used multiple times on the command line.
 
 If the optional I<filter> is provided, the stats will only be calculated
 on those calls that match that filter.
 
-Example: S<B<-z dcerpc,rtt,12345778-1234-abcd-ef00-0123456789ac,1.0,ip.addr==1.2.3.4>>
-will collect SAMR RTT statistics for a specific host.
-
-This option can be used multiple times on the command line.
+Example: S<B<-z dcerpc,srt,12345778-1234-abcd-ef00-0123456789ac,1.0,ip.addr==1.2.3.4>> will collect SAMR
+SRT statistics for a specific host.
 
 =item B<-z> io,phs[,I<filter>]
 
@@ -846,25 +850,26 @@ Several fields with same name within one diameter message are supported, e.g. I<
 
 Note: B<tshark -q> option is recommended to suppress default B<tshark> output.
 
-=item B<-z> rpc,rtt,I<program>,I<version>[,I<filter>]
+=item B<-z> rpc,srt,I<program>,I<version>[,I<filter>]
 
-Collect call/reply RTT data for I<program>/I<version>.  Data collected
-is number of calls for each procedure, MinRTT, MaxRTT and AvgRTT.
-Example: B<-z rpc,rtt,100003,3> will collect data for NFS v3.
+Collect call/reply SRT (Service Response Time) data for I<program>/I<version>.  Data collected
+is number of calls for each procedure, MinSRT, MaxSRT and AvgSRT.
+
+Example: B<-z rpc,srt,100003,3> will collect data for NFS v3.
+
+This option can be used multiple times on the command line.
 
 If the optional I<filter> is provided, the stats will only be calculated
 on those calls that match that filter.
 
-Example: B<-z rpc,rtt,100003,3,nfs.fh.hash==0x12345678> will collect NFS v3
-RTT statistics for a specific file.
-
-This option can be used multiple times on the command line.
+Example: B<-z rpc,srt,100003,3,nfs.fh.hash==0x12345678> will collect NFS v3
+SRT statistics for a specific file.
 
 =item B<-z> rpc,programs
 
-Collect call/reply RTT data for all known ONC-RPC programs/versions.
-Data collected is number of calls for each protocol/version, MinRTT,
-MaxRTT and AvgRTT.
+Collect call/reply SRT data for all known ONC-RPC programs/versions.
+Data collected is number of calls for each protocol/version, MinSRT,
+MaxSRT and AvgSRT.
 This option can only be used once on the command line.
 
 =item B<-z> rtp,streams
@@ -872,11 +877,32 @@ This option can only be used once on the command line.
 Collect statistics for all RTP streams and calculate max. delta, max. and
 mean jitter and packet loss percentages.
 
-=item B<-z> smb,rtt[,I<filter>]
+=item B<-z> scsi,srt,I<cmdset>[,<filter>]
+
+Collect call/reply SRT (Service Response Time) data for SCSI commandset <cmdset>.
+
+Commandsets are 0:SBC   1:SSC  5:MMC
+
+Data collected
+is the number of calls for each procedure, MinSRT, MaxSRT and AvgSRT.
+
+Example: B<-z scsi,srt,0> will collect data for SCSI BLOCK COMMANDS (SBC).
+
+This option can be used multiple times on the command line.
+
+If the optional I<filter> is provided, the stats will only be calculated
+on those calls that match that filter.
+
+Example: B<-z scsi,srt,0,ip.addr==1.2.3.4> will collect SCSI SBC
+SRT statistics for a specific iscsi/ifcp/fcip host.
+
+=item B<-z> smb,srt[,I<filter>]
+
+Collect call/reply SRT (Service Response Time) data for SMB.  Data collected
+is number of calls for each SMB command, MinSRT, MaxSRT and AvgSRT.
+
+Example: B<-z smb,srt>
 
-Collect call/reply RTT data for SMB.  Data collected
-is number of calls for each SMB command, MinRTT, MaxRTT and AvgRTT.
-Example: B<-z smb,rtt>.
 The data will be presented as separate tables for all normal SMB commands,
 all Transaction2 commands and all NT Transaction commands.
 Only those commands that are seen in the capture will have its stats
@@ -891,7 +917,7 @@ This option can be used multiple times on the command line.
 If the optional I<filter> is provided, the stats will only be calculated
 on those calls that match that filter.
 
-Example: B<-z "smb,rtt,ip.addr==1.2.3.4"> will only collect stats for
+Example: B<-z "smb,srt,ip.addr==1.2.3.4"> will only collect stats for
 SMB packets exchanged by the host at IP address 1.2.3.4 .
 
 =item B<-z> smb,sids
@@ -911,7 +937,7 @@ is relatively restricted with a hope of future expansion.
 =item B<-z> mgcp,rtd[I<,filter>]
 
 Collect requests/response RTD (Response Time Delay) data for MGCP.
-(This is similar to B<-z smb,rtt>). Data collected is the number of calls
+(This is similar to B<-z smb,srt>). Data collected is the number of calls
 for each known MGCP Type, MinRTD, MaxRTD and AvgRTD.
 Additionally you get the number of duplicate requests/responses,
 unresponded requests, responses, which don't match with any request.
@@ -927,7 +953,7 @@ MGCP packets exchanged by the host at IP address 1.2.3.4 .
 =item B<-z> megaco,rtd[I<,filter>]
 
 Collect requests/response RTD (Response Time Delay) data for MEGACO.
-(This is similar to B<-z smb,rtt>). Data collected is the number of calls
+(This is similar to B<-z smb,srt>). Data collected is the number of calls
 for each known MEGACO Type, MinRTD, MaxRTD and AvgRTD.
 Additionally you get the number of duplicate requests/responses,
 unresponded requests, responses, which don't match with any request.
@@ -960,18 +986,20 @@ This option can be used multiple times on the command line.
 
 Collect requests/response SRT (Service Response Time) data for ITU-T H.225 RAS.
 Data collected is number of calls of each ITU-T H.225 RAS Message Type,
-Minimum SRT, Maximum SRT, Average SRT, Minimum in Frame, and Maximum in Frame.
+Minimum SRT, Maximum SRT, Average SRT, Minimum in Packet, and Maximum in Packet.
 You will also get the number of Open Requests (Unresponded Requests),
 Discarded Responses (Responses without matching request) and Duplicate Messages.
-Example: B<-z h225,srt>.
+
+Example: B<-z h225,srt>
+
+This option can be used multiple times on the command line.
 
 If the optional I<filter> is provided, the stats will only be calculated
 on those calls that match that filter.
+
 Example: B<-z "h225,srt,ip.addr==1.2.3.4"> will only collect stats for
 ITU-T H.225 RAS packets exchanged by the host at IP address 1.2.3.4 .
 
-This option can be used multiple times on the command line.
-
 =item B<-z> sip,stat[I<,filter>]
 
 This option will activate a counter for SIP messages. You will get the number
index 7f046eb985db5b780530bda5d48b43d959bac64c..25d1cb8a5a8eb90211ad19544c8d69eacea9fb53 100644 (file)
@@ -571,9 +571,9 @@ SRT statistics for a specific file.
 
 =item B<-z> rpc,programs
 
-Collect call/reply RTT data for all known ONC-RPC programs/versions.
-Data collected is the number of calls for each protocol/version, MinRTT,
-MaxRTT and AvgRTT.
+Collect call/reply SRT data for all known ONC-RPC programs/versions.
+Data collected is the number of calls for each protocol/version, MinSRT,
+MaxSRT and AvgSRT.
 
 =item B<-z> scsi,srt,I<cmdset>[,<filter>]
 
@@ -1640,7 +1640,7 @@ Count/Rate/Percent by IP Protocol Types
 
 =item Statistics:ONC-RPC Programs
 
-This dialog will open a window showing aggregated RTT statistics for all
+This dialog will open a window showing aggregated SRT statistics for all
 ONC-RPC Programs/versions that exist in the capture file.
 
 =item Statistics:TCP Stream Graph
diff --git a/mkcap.c b/mkcap.c
index 6a02029317acc0ee782a894e93f82dd7fe6b1dc9..c246c65f84a2fee66bc6e43ec661d8b79cff1823 100644 (file)
--- a/mkcap.c
+++ b/mkcap.c
@@ -492,7 +492,7 @@ makeackedrundroppedtail8kb(int len, int spacing, int ackdelay)
 void usage()
 {
   fprintf(stderr, "Usage: mkcap [OPTIONS], where\n");
-  fprintf(stderr, "\t-a <ack-delay>        is the delay to an ACK (RTT)\n");
+  fprintf(stderr, "\t-a <ack-delay>        is the delay to an ACK (SRT)\n");
   fprintf(stderr, "\t-b <bytes-to-send>    is the bytes to send on connection\n");
   fprintf(stderr, "\t-i <ip-addr-hex>      is the sender IP address in hex\n");
   fprintf(stderr, "\t-I <ip-addr-hex>      is the recipient IP address in hex\n");
index 0465decc6dc36a6de36eb86ee529e4955eabc19d..e1960f474daf664110914f92565a077b23d5ac14 100644 (file)
@@ -81,9 +81,9 @@ afpstat_draw(void *pss)
        guint64 td;
        printf("\n");
        printf("===================================================================\n");
-       printf("AFP RTT Statistics:\n");
+       printf("AFP SRT Statistics:\n");
        printf("Filter: %s\n",ss->filter?ss->filter:"");
-       printf("Commands                   Calls   Min RTT   Max RTT   Avg RTT\n");
+       printf("Commands                   Calls   Min SRT   Max SRT   Avg SRT\n");
        for(i=0;i<256;i++){
                /* nothing seen, nothing to do */
                if(ss->proc[i].num==0){
@@ -119,7 +119,7 @@ afpstat_init(const char *optarg, void* userdata _U_)
        const char *filter=NULL;
        GString *error_string;
 
-       if(!strncmp(optarg,"afp,rtt,",8)){
+       if(!strncmp(optarg,"afp,srt,",8)){
                filter=optarg+8;
        } else {
                filter=NULL;
@@ -150,7 +150,7 @@ afpstat_init(const char *optarg, void* userdata _U_)
                g_free(ss->filter);
                g_free(ss);
 
-               fprintf(stderr, "tshark: Couldn't register afp,rtt tap: %s\n",
+               fprintf(stderr, "tshark: Couldn't register afp,srt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
@@ -160,5 +160,5 @@ afpstat_init(const char *optarg, void* userdata _U_)
 void
 register_tap_listener_afpstat(void)
 {
-       register_stat_cmd_arg("afp,rtt", afpstat_init,NULL);
+       register_stat_cmd_arg("afp,srt", afpstat_init,NULL);
 }
index b61e09333f49a7236bcf6deaeb04af7be1b3698d..dd3aab0418e19ebf9624a2093a021c10b38649d9 100644 (file)
@@ -277,14 +277,14 @@ rpcstat_init(const char *optarg, void* userdata _U_)
        const char *filter=NULL;
        GString *error_string;
 
-       if(sscanf(optarg,"rpc,rtt,%d,%d,%n",&program,&version,&pos)==2){
+       if(sscanf(optarg,"rpc,srt,%d,%d,%n",&program,&version,&pos)==2){
                if(pos){
                        filter=optarg+pos;
                } else {
                        filter=NULL;
                }
        } else {
-               fprintf(stderr, "tshark: invalid \"-z rpc,rtt,<program>,<version>[,<filter>]\" argument\n");
+               fprintf(stderr, "tshark: invalid \"-z rpc,srt,<program>,<version>[,<filter>]\" argument\n");
                exit(1);
        }
 
@@ -339,7 +339,7 @@ rpcstat_init(const char *optarg, void* userdata _U_)
                g_free(rs->filter);
                g_free(rs);
 
-               fprintf(stderr, "tshark: Couldn't register rpc,rtt tap: %s\n",
+               fprintf(stderr, "tshark: Couldn't register rpc,srt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
@@ -350,6 +350,6 @@ rpcstat_init(const char *optarg, void* userdata _U_)
 void
 register_tap_listener_rpcstat(void)
 {
-       register_stat_cmd_arg("rpc,rtt,", rpcstat_init,NULL);
+       register_stat_cmd_arg("rpc,srt,", rpcstat_init,NULL);
 }
 
index 38911b08a02aff1933055be37542336341422b1d..c12d78cb72ee698cc53f0851abdc87f2a49eec3d 100644 (file)
@@ -149,9 +149,9 @@ scsistat_draw(void *prs)
 
        printf("\n");
        printf("===========================================================\n");
-       printf("SCSI %s RTT Statistics:\n", rs->prog);
+       printf("SCSI %s SRT Statistics:\n", rs->prog);
        printf("Filter: %s\n", rs->filter?rs->filter:"");
-       printf("Procedure            Calls   Min RTT    Max RTT    Avg RTT\n");
+       printf("Procedure            Calls   Min SRT    Max SRT    Avg SRT\n");
        for(i=0; i < MAX_PROCEDURES; i++) {
                if(rs->procedures[i].num==0) {
                        continue;
@@ -183,14 +183,14 @@ scsistat_init(const char *optarg, void* userdata _U_)
        GString *error_string;
 
        pos=0;
-       if(sscanf(optarg, "scsi,rtt,%d,%n", &program, &pos)==1) {
+       if(sscanf(optarg, "scsi,srt,%d,%n", &program, &pos)==1) {
                if(pos) {
                        filter=optarg+pos;
                } else {
                        filter=NULL;
                }
        } else {
-               fprintf(stderr, "tshark: invalid \"-z scsi,rtt,<cmdset>[,<filter>]\" argument\n");
+               fprintf(stderr, "tshark: invalid \"-z scsi,srt,<cmdset>[,<filter>]\" argument\n");
                exit(1);
        }
 
@@ -249,7 +249,7 @@ scsistat_init(const char *optarg, void* userdata _U_)
                g_free(rs->filter);
                g_free(rs);
 
-               fprintf(stderr, "tshark: Couldn't register scsi,rtt tap: %s\n",
+               fprintf(stderr, "tshark: Couldn't register scsi,srt tap: %s\n",
                        error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
@@ -259,6 +259,6 @@ scsistat_init(const char *optarg, void* userdata _U_)
 void
 register_tap_listener_scsistat(void)
 {
-       register_stat_cmd_arg("scsi,rtt,", scsistat_init, NULL);
+       register_stat_cmd_arg("scsi,srt,", scsistat_init, NULL);
 }
 
index ac7d4f019f85736cdf906384c5f790bede38cfe7..2a3439e6e1f6bb4777dc0579c031d3c0bf708668 100644 (file)
@@ -193,7 +193,7 @@ smbstat_init(const char *optarg,void* userdata _U_)
        const char *filter=NULL;
        GString *error_string;
 
-       if(!strncmp(optarg,"smb,rtt,",8)){
+       if(!strncmp(optarg,"smb,srt,",8)){
                filter=optarg+8;
        } else {
                filter=NULL;
@@ -244,7 +244,7 @@ smbstat_init(const char *optarg,void* userdata _U_)
                g_free(ss->filter);
                g_free(ss);
 
-               fprintf(stderr, "tshark: Couldn't register smb,rtt tap: %s\n",
+               fprintf(stderr, "tshark: Couldn't register smb,srt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
@@ -255,6 +255,6 @@ smbstat_init(const char *optarg,void* userdata _U_)
 void
 register_tap_listener_smbstat(void)
 {
-       register_stat_cmd_arg("smb,rtt", smbstat_init,NULL);
+       register_stat_cmd_arg("smb,srt", smbstat_init,NULL);
 }
 
index a318a8163814c82b79652cd7fa31c2bb37d7f9c5..40bce6cefc203a75a788073085c14ce9b37de472 100644 (file)
@@ -49,7 +49,7 @@ typedef struct _wsp_pdu_t {
        const gchar     *type;
        guint32          packets;
 } wsp_pdu_t;
/* used to keep track of RTT statistics */
 typedef struct _wsp_status_code_t {
        const gchar     *name;
        guint32          packets;
@@ -49,7 +49,7 @@ typedef struct _wsp_pdu_t {
        guint32          packets;
 } wsp_pdu_t;
-/* used to keep track of RTT statistics */
+/* used to keep track of SRT statistics */
 typedef struct _wsp_status_code_t {
        const gchar     *name;